import { Directive, ElementRef, Input, HostListener, NgModule } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxPatternDirective {
    /**
     * @param {?} host
     */
    constructor(host) {
        this.host = host;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (this.ngxPattern) {
            if (typeof this.ngxPattern === 'string') {
                this.regex = new RegExp(`^${this.ngxPattern}$`, 'g');
            }
            else {
                this.regex = this.ngxPattern;
            }
        }
    }
    /**
     * @param {?} e
     * @return {?}
     */
    onKeyPress(e) {
        if (this.regex && !e.ctrlKey && !isSpecialKey(e.key)) {
            if (!this.validWithChange(e.key)) {
                e.preventDefault();
            }
        }
    }
    /**
     * @param {?} e
     * @return {?}
     */
    onPaste(e) {
        /** @type {?} */
        const pastedInput = e.clipboardData.getData('text/plain');
        if (!this.validWithChange(pastedInput)) {
            e.preventDefault();
        }
    }
    /**
     * @param {?} e
     * @return {?}
     */
    onDrop(e) {
        /** @type {?} */
        const textData = e.dataTransfer.getData('text');
        if (!this.validWithChange(textData)) {
            e.preventDefault();
        }
    }
    /**
     * @private
     * @param {?} delta
     * @return {?}
     */
    validWithChange(delta) {
        const { value: current, selectionStart, selectionEnd, } = this.inputEl;
        /** @type {?} */
        const updated = current.substring(0, selectionStart) + delta + current.substring(selectionEnd + 1);
        /** @type {?} */
        const result = !updated || this.regex.test(updated);
        this.regex.lastIndex = 0;
        return result;
    }
    /**
     * @return {?}
     */
    get inputEl() {
        return this.host.nativeElement;
    }
}
NgxPatternDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngxPattern]'
            },] }
];
/** @nocollapse */
NgxPatternDirective.ctorParameters = () => [
    { type: ElementRef }
];
NgxPatternDirective.propDecorators = {
    ngxPattern: [{ type: Input }],
    onKeyPress: [{ type: HostListener, args: ['keydown', ['$event'],] }],
    onPaste: [{ type: HostListener, args: ['paste', ['$event'],] }],
    onDrop: [{ type: HostListener, args: ['drop', ['$event'],] }]
};
if (false) {
    /** @type {?} */
    NgxPatternDirective.prototype.ngxPattern;
    /**
     * @type {?}
     * @private
     */
    NgxPatternDirective.prototype.regex;
    /**
     * @type {?}
     * @private
     */
    NgxPatternDirective.prototype.host;
}
/**
 * @see https://developer.mozilla.org/bg/docs/Web/API/KeyboardEvent/key/Key_Values
 * @param {?} key
 * @return {?}
 */
function isSpecialKey(key) {
    return key.length > 1;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxPatternModule {
}
NgxPatternModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NgxPatternDirective],
                imports: [],
                exports: [
                    NgxPatternDirective
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { NgxPatternDirective, NgxPatternModule };
//# sourceMappingURL=ngx-pattern.js.map
